#
# spec file for package pgloader
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pgloader
Version:        3.6.1
Release:        lp152.2.67
Summary:        Fast data loader for PostgreSQL
License:        PostgreSQL
Group:          Productivity/Databases/Tools
URL:            https://pgloader.io
Source0:        https://github.com/dimitri/%{name}/releases/download/v%{version}/%{name}-bundle-%{version}.tgz
BuildRequires:  fdupes
BuildRequires:  freetds-devel
BuildRequires:  pkgconfig
BuildRequires:  sbcl
%if 0%{?leap_version} >= 430000 || 0%{?suse_version} > 4300
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libopenssl)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
%else
BuildRequires:  libopenssl-devel
%endif
BuildRequires:  pkgconfig(sqlite3)

%description
pgloader imports data from different kind of sources and COPY it into
PostgreSQL.

The command language is described in the manual page and allows to describe
where to find the data source, its format, and to describe data processing
and transformation.

Supported source formats include SQL Server, CSV, fixed width flat files,
dBase3 files (DBF), and SQLite and MySQL databases. In most of those formats,
pgloader is able to auto-discover the schema and create the tables and the
indexes in PostgreSQL. In the MySQL case it's possible to edit CASTing rules
from the pgloader command directly.

%prep
%setup -q -n %{name}-bundle-%{version}

%build
export CCFLAGS="%{_optflags}"
export CCXFLAGS="%{_optflags}"
export DYNSIZE=""
echo "Arch is : %{_arch}"
%if "%{_arch}" == "i386" || "%{_arch}" == "arm"
export DYNSIZE="DYNSIZE=1024"
%endif
make V=1 %{?_smp_mflags} ${DYNSIZE}

%install
install -d %{buildroot}%{_bindir}
install -m 755 bin/pgloader %{buildroot}%{_bindir}/pgloader

%fdupes %{buildroot}

%files
%defattr(-,root,root,-)
%license local-projects/%{name}-%{version}/LICENSE
%doc local-projects/%{name}-%{version}/README.md local-projects/%{name}-%{version}/TODO.md
%{_bindir}/pgloader

%changelog
* Mon Mar  4 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.6.1
  This release contains three major themes: usual maintenance and
  bug fixing, support for new database systems as sources and
  targets, and support for Citus distribution.
  https://github.com/dimitri/pgloader/releases/tag/v3.6.1
- Packaging: update date
* Fri Sep  7 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 3.5.2
  + A lot of changes details at
  + https://github.com/dimitri/pgloader/compare/v3.4.1...v3.5.2
- Packaging:
  + spec-cleaner with pkgconfig (but keep Leap 42.3 building)
  + Remove man1 there's no more available
  + Use %%license only remove obsolete if dist
  + Remove Buildrequires python* not needed
  + Add arm in the DYNSIZE=1024 4096 is too much
* Sun Dec  3 2017 bruno@ioda-net.ch
- Update to last 3.4.1 upstream version
  + Have a look at readme and https://pgloader.io numerous changes
    happened between previous 2.3.2 and 3.4.1
- Packaging:
  + spec-cleaner : Adding full header
  + remove old pgloader-makefile.patch (Python makefile)
  + Add and remove buildrequires (-python +lisp)
  + Fix License pgloader is PostgreSQL licenced (still BSD)
  + Fix URL and source
  + Adapt description to upstream
  + Bundle is used due to the lack of lisp packages
  + Use DYNSIZE=1024 for 32bits
- Binary is using gethostbyname(), and don't use -fpie due to sbcl
* Tue Dec 27 2011 darin@darins.net
- fixed non-standard usage of %%doc
* Tue Dec 27 2011 darin@darins.net
- removed BuildArch
- fixed non-standard group
- added %%build and python-base require
* Tue Dec 27 2011 darin@darins.net
- Adapted .spec for OpenSuSE
- moved %%changelog to .changes file
- Added py_compile and fdupes
  http://en.opensuse.org/openSUSE:Packaging_Python#Byte_Compiled_Files
* Tue Jul 28 2009 Devrim Gunduz <devrim@CommandPrompt.com> 2.3.2-1
- Update to 2.3.2
* Sun Jun 15 2008 Devrim Gunduz <devrim@CommandPrompt.com> 2.3.1-1
- Update to 2.3.1
* Wed Apr  9 2008 Devrim Gunduz <devrim@CommandPrompt.com> 2.3.0-1
- Update to 2.3.0
- Various spec file fixes
* Fri Feb  1 2008 Devrim Gunduz <devrim@CommandPrompt.com> 2.2.6-1
- Update to 2.2.6
* Sat Jan 19 2008 Devrim Gunduz <devrim@CommandPrompt.com> 2.2.5-1
- Update to 2.2.5
* Thu Jun 21 2007 Devrim Gunduz <devrim@CommandPrompt.com> 2.2.0-1
- Initial packaging
